/* LibraryContainer.h */

/* Copyright (C) 2011-2015  Lucio Carreras
 *
 * This file is part of sayonara player
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */



#ifndef LIBRARYCONTAINER_H
#define LIBRARYCONTAINER_H

#include <QIcon>
#include <QWidget>
#include <QComboBox>



/**
 * @brief An interface class needed when implementing a library plugin
 */
class LibraryContainerInterface :
	public QObject
{
	Q_OBJECT

public:

	explicit LibraryContainerInterface(QObject* parent=nullptr);
	virtual ~LibraryContainerInterface();

	/**
	 * @brief Should return the icon displayed in the library view combobox
	 * @return QIcon instance
	 */
	virtual QIcon				get_icon() const=0;


	/**
	 * @brief Should return an untranslated name used for identifying this widget
	 * @return name
	 */
	virtual QString				get_name() const=0;

	/**
	 * @brief Should return the translated name displayed in the library view combobox
	 * @return display name
	 */
	virtual QString				get_display_name() const=0;

	/**
	 * @brief Should return the UI for the library view
	 * @return pointer to the ui
	 */
	virtual QWidget*			get_ui() const=0;

	/**
	 * @brief Should return the library chooser combo box
	 * @return pointer to the combobox
	 */
	virtual QComboBox*			get_libchooser()=0;

};

Q_DECLARE_INTERFACE(LibraryContainerInterface, "com.sayonara-player.library")

#endif // LIBRARYCONTAINER_H
